..
    This file is part of Invenio.
    Copyright (C) 2015-2021 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Changes
=======

Version 2.2.4 (released 2021-04-29)
-----------------------------------

- Initial public release.
